==> tine20-allinone_2020.03.4.tar.bz2: Setup/js/Setup-lang-ca-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Catalan (http://www.transifex.com/tine20/tine20/language/ca/)\nLanguage: ca\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "I have read the license agreement and accept it"
: "He llegit i acceptat l'acord de llicència"

, "License Agreement"
: "Acord de llicència"

, "I have read the privacy agreement and accept it"
: "He llegit i acceptat l'acord de privadesa"

, "Privacy Agreement"
: "Acord de privadesa"

, "Accept Terms and Conditions"
: "Accepta els termes i condicions"

, "Backend"
: "Administració"

, "Standard IMAP"
: "IMAP estàndard"

, "Standard SMTP"
: "SMTP estàndard"

, "Imap"
: "Imap"

, "Hostname"
: "Nom de l'amfitrió"

, "Username"
: "Nom d'usuari"

, "Password"
: "Contrasenya"

, "Port"
: "Port"

, "Secure Connection"
: "Connexió segura"

, "None"
: "Cap"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Verify peer Certificate"
: ""

, "Use system account"
: "Utilitza el compte de sistema"

, "No"
: "No"

, "Yes"
: "Sí"

, "Append domain to login name"
: "Afegeix el domini al nom d'inici de sessió"

, "Use email address as login name"
: ""

, "Cyrus Admin"
: ""

, "Cyrus Admin Password"
: ""

, "Use proxy auth"
: ""

, "Smtp"
: "Smtp"

, "Authentication"
: "Autenticació"

, "Login"
: "Inici de sessió"

, "Plain"
: "Pla"

, "Primary Domain"
: "Domini primari"

, "Secondary Domains (comma separated)"
: "Dominis secundaris (separats per comes)"

, "Notifications service address"
: "Adreça del servei de notificacions"

, "Notification Username"
: "Nom d'usuari de notificació"

, "Notification Password"
: "Contrasenya de notificació"

, "Notifications local client (hostname or IP address)"
: ""

, "SIEVE"
: ""

, "MySql Hostname"
: "Nom de l'amfitrió MySql"

, "MySql Database"
: "Base de dades MySql"

, "MySql User"
: "Usuari MySql"

, "MySql Password"
: "Contrasenya MySql"

, "MySql Port"
: "Port MySql"

, "User or UID"
: ""

, "Group or GID"
: ""

, "Home Template"
: ""

, "Password Scheme"
: ""

, "PLAIN-MD5"
: ""

, "MD5-CRYPT"
: ""

, "SHA1"
: ""

, "SHA256"
: ""

, "SSHA256"
: ""

, "SHA512"
: ""

, "SSHA512"
: ""

, "PLAIN"
: ""

, "Terms and Conditions"
: "Termes i condicions"

, "Setup Checks"
: "Proves de configuració"

, "Config Manager"
: "Gestor de configuracions"

, "Authentication/Accounts"
: "Autenticació/Comptes"

, "Email"
: "Correu electrònic"

, "Application Manager"
: "Gestor d'aplicacions"

, "Setup"
: ""

, "Name"
: "Nom"

, "Enabled"
: "Habilitat"

, "Order"
: "Ordre"

, "Installed Version"
: "Versió instal·lada"

, "Available Version"
: "Versió disponible"

, "Status"
: "Estat"

, "Depends on"
: "Depèn de"

, "Install application"
: "Instal·la aplicació"

, "Uninstall application"
: "Desinstal·la aplicació"

, "Update application"
: "Actualitza aplicació"

, "Go to {0} login"
: "Vés a l'inici de sessió de {0}"

, "uninstall"
: "desinstal·la"

, "Do you really want to uninstall the application(s)?"
: "Esteu segur que voleu deinstal·lar l'aplicació o aplicacions?"

, "This may take a while"
: "Això pot tardar una estona"

, "Dependency Violation"
: "S'ha produït una violació de dependències"

, "CLI Required"
: ""

, "Delete all existing users and groups"
: "Elimina tots els usuaris i grups existents"

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: "El canvi d'SQL a LDAP eliminarà tots els comptes d'usuari, els grups i els rols existents. Esteu segur que voleu canviar l'administració d'emmagatzematge de comptes a LDAP?"

, "TLS client certificate"
: ""

, "Initial Admin User"
: ""

, "Initial admin login name"
: "Nom d'inici de sessió administratiu inicial"

, "Initial admin Password"
: "Contrasenya administrativa inicial"

, "Password confirmation"
: "Confirmació de la contrasenya"

, "Authentication provider"
: "Proveïdor d'autenticació"

, "Try to split username"
: ""

, "Account canonical form"
: "Forma canònica del compte"

, "Account domain name"
: ""

, "Account domain short name"
: "Nom curt de domini del compte"

, "Host"
: "Amfitrió"

, "Login name"
: "Nom d'inici de sessió"

, "Bind requires DN"
: "La vinculació requereix DN"

, "Start TLS"
: ""

, "Base DN"
: "DN base"

, "Search filter"
: "Filtre de cerca"

, "Certificate validation"
: ""

, "CA file"
: ""

, "CRL directory"
: ""

, "Accounts storage"
: "Emmagatzematge de comptes"

, "Default user group name"
: "Nom de grup d'usuari per defecte"

, "Default admin group name"
: "Nom de grup d'administració per defecte"

, "Login panel"
: ""

, "Reuse last username logged"
: ""

, "Password Settings"
: ""

, "User can change password"
: "L'usuari pot canviar la contrasenya"

, "Enable password policy"
: ""

, "Only ASCII"
: ""

, "Minimum length"
: ""

, "Minimum word chars"
: ""

, "Minimum uppercase chars"
: ""

, "Minimum special chars"
: ""

, "Minimum numbers"
: ""

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: ""

, "Redirect Settings"
: "Configuració de redireccionament"

, "Redirect Url (redirect to login screen if empty)"
: "Url on redirigir (es redirigeix a la pantalla d'inici de sessió si ho deixeu buit)"

, "Redirect Always (if No, only redirect after logout)"
: "Sempre es redirigeix (si poseu No, només es redirigirà després d'un tancament de sessió)"

, "Redirect to referring site, if exists"
: "Si existeix, es redirigeix al lloc referent"

, "Password encoding"
: "Codificació de la contrasenya"

, "des"
: ""

, "crypt"
: ""

, "blowfish_crypt"
: ""

, "md5_crypt"
: ""

, "ext_crypt"
: ""

, "md5"
: ""

, "smd5"
: ""

, "sha"
: ""

, "ssha"
: ""

, "ntpassword"
: ""

, "plain"
: ""

, "User DN"
: "DN d'usuari"

, "User Filter"
: "Filtre d'usuari"

, "User Search Scope"
: "Abast de la cerca d'usuari"

, "Groups DN"
: "DN de grups"

, "Group Filter"
: "Filtre de grup"

, "Group Search Scope"
: "Abast de la cerca de grup"

, "Use Rfc 2307 bis"
: "Utilitza Rfc 2307 bis"

, "Maintain RFC 2307 attributes"
: ""

, "Min User Id"
: "Identificador d'usuari mínim"

, "Max User Id"
: "Identificador d'usuari màxim"

, "Min Group Id"
: "Identificador de grup mínim"

, "Max Group Id"
: "Identificador de grup màxim"

, "Group UUID Attribute name"
: "Nom d'atribut UUID de grup"

, "User UUID Attribute name"
: "Nom d'atribut UUID d'usuari"

, "Readonly access"
: ""

, "Save config and install"
: "Desa la configuració i instal·la"

, "Save config"
: "Desa la configuració"

, "Passwords don't match"
: "Les contrasenyes no coincideixen"

, "Should not be empty"
: "No pot ser buit"

, "Performing Environment Checks..."
: "Es realitzen comprovacions d'entorn..."

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: ""

, "Check"
: "Comprova"

, "Result"
: "Resultat"

, "Error"
: "Error"

, "Run setup tests"
: "Executa proves de configuració"

, "Ignore setup tests"
: "Ignora les proves de configuració"

, "Application, Applications"
: [
  "Aplicació"
 ,"Aplicacions"

]
, "File"
: ""

, "Setup Authentication"
: "Estableix l'autenticació"

, "Database"
: "Base de dades"

, "User"
: "Usuari"

, "Prefix"
: "Prefix"

, "Logging"
: "Registre d'esdeveniments"

, "Filename"
: "Nom de fitxer"

, "Priority"
: "Prioritat"

, "Caching"
: "Emmagatzematge cau"

, "Lifetime (seconds)"
: "temps de vida (segons)"

, "Path"
: "Camí"

, "Queue"
: ""

, "Session"
: ""

, "Temporary files"
: "Fitxers temporals"

, "Temporary Files Path"
: "Camí als fitxers temporals"

, "Filestore directory"
: ""

, "Filestore Path"
: ""

, "Addressbook Map panel"
: "Tauler Mapa de llibreta d'adreces"

, "Map panel"
: "Tauler Mapa"

, "disabled"
: "inhabilitat"

, "enabled"
: "habilitat"

, "Config file is not writable"
: "El fitxer de configuració no es pot escriure"

, "Download config file"
: "Descarrega el fitxer de configuració"

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Application"
: "Aplicació"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Setup/js/Setup-lang-ca-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:59+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Catalan (http://www.transifex.com/tine20/tine20/language/ca/)\nLanguage: ca\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Performing Environment Checks..."
: "Es realitzen comprovacions d'entorn..."

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: ""

, "Check"
: "Comprova"

, "Result"
: "Resultat"

, "Message"
: ""

, "Run setup tests"
: "Executa proves de configuració"

, "Ignore setup tests"
: "Ignora les proves de configuració"

, "Install application"
: "Instal·la aplicació"

, "Name"
: "Nom"

, "Enabled"
: "Habilitat"

, "Order"
: "Ordre"

, "Installed Version"
: "Versió instal·lada"

, "Available Version"
: "Versió disponible"

, "Status"
: "Estat"

, "Depends on"
: "Depèn de"

, "Uninstall application"
: "Desinstal·la aplicació"

, "Update applications"
: ""

, "Go to {0} login"
: "Vés a l'inici de sessió de {0}"

, "uninstall"
: "desinstal·la"

, "Do you really want to uninstall the application(s)?"
: "Esteu segur que voleu deinstal·lar l'aplicació o aplicacions?"

, "This may take a while"
: "Això pot tardar una estona"

, "Dependency Violation"
: "S'ha produït una violació de dependències"

, "CLI Required"
: ""

, "Delete all existing users and groups"
: "Elimina tots els usuaris i grups existents"

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: "El canvi d'SQL a LDAP eliminarà tots els comptes d'usuari, els grups i els rols existents. Esteu segur que voleu canviar l'administració d'emmagatzematge de comptes a LDAP?"

, "Backend"
: "Administració"

, "TLS client certificate"
: ""

, "Initial Admin User"
: ""

, "Initial admin login name"
: "Nom d'inici de sessió administratiu inicial"

, "Initial admin Password"
: "Contrasenya administrativa inicial"

, "Password confirmation"
: "Confirmació de la contrasenya"

, "Authentication provider"
: "Proveïdor d'autenticació"

, "Try to split username"
: ""

, "Yes"
: "Sí"

, "No"
: "No"

, "Account canonical form"
: "Forma canònica del compte"

, "Account domain name"
: ""

, "Account domain short name"
: "Nom curt de domini del compte"

, "Host"
: "Amfitrió"

, "Login name"
: "Nom d'inici de sessió"

, "Password"
: "Contrasenya"

, "Bind requires DN"
: "La vinculació requereix DN"

, "Start TLS"
: ""

, "SSL"
: "SSL"

, "Port"
: "Port"

, "Base DN"
: "DN base"

, "Search filter"
: "Filtre de cerca"

, "Hostname"
: "Nom de l'amfitrió"

, "Secure Connection"
: "Connexió segura"

, "None"
: "Cap"

, "TLS"
: "TLS"

, "Append domain to login name"
: "Afegeix el domini al nom d'inici de sessió"

, "Certificate validation"
: ""

, "CA file"
: ""

, "CRL directory"
: ""

, "Accounts storage"
: "Emmagatzematge de comptes"

, "Default user group name"
: "Nom de grup d'usuari per defecte"

, "Default admin group name"
: "Nom de grup d'administració per defecte"

, "Login panel"
: ""

, "Reuse last username logged"
: ""

, "Password Settings"
: ""

, "User can change password"
: "L'usuari pot canviar la contrasenya"

, "Enable password policy"
: ""

, "Only ASCII"
: ""

, "Minimum length"
: ""

, "Minimum word chars"
: ""

, "Minimum uppercase chars"
: ""

, "Minimum special chars"
: ""

, "Minimum numbers"
: ""

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: ""

, "Redirect Settings"
: "Configuració de redireccionament"

, "Redirect Url (redirect to login screen if empty)"
: "Url on redirigir (es redirigeix a la pantalla d'inici de sessió si ho deixeu buit)"

, "Redirect Always (if No, only redirect after logout)"
: "Sempre es redirigeix (si poseu No, només es redirigirà després d'un tancament de sessió)"

, "Redirect to referring site, if exists"
: "Si existeix, es redirigeix al lloc referent"

, "Password encoding"
: "Codificació de la contrasenya"

, "des"
: ""

, "crypt"
: ""

, "blowfish_crypt"
: ""

, "md5_crypt"
: ""

, "ext_crypt"
: ""

, "md5"
: ""

, "smd5"
: ""

, "sha"
: ""

, "ssha"
: ""

, "ntpassword"
: ""

, "plain"
: ""

, "User DN"
: "DN d'usuari"

, "User Filter"
: "Filtre d'usuari"

, "User Search Scope"
: "Abast de la cerca d'usuari"

, "Groups DN"
: "DN de grups"

, "Group Filter"
: "Filtre de grup"

, "Group Search Scope"
: "Abast de la cerca de grup"

, "Use Rfc 2307 bis"
: "Utilitza Rfc 2307 bis"

, "Maintain RFC 2307 attributes"
: ""

, "Min User Id"
: "Identificador d'usuari mínim"

, "Max User Id"
: "Identificador d'usuari màxim"

, "Min Group Id"
: "Identificador de grup mínim"

, "Max Group Id"
: "Identificador de grup màxim"

, "Group UUID Attribute name"
: "Nom d'atribut UUID de grup"

, "User UUID Attribute name"
: "Nom d'atribut UUID d'usuari"

, "Readonly access"
: ""

, "Save config and install"
: "Desa la configuració i instal·la"

, "Save config"
: "Desa la configuració"

, "Passwords don't match"
: "Les contrasenyes no coincideixen"

, "Should not be empty"
: "No pot ser buit"

, "File"
: ""

, "Setup Authentication"
: "Estableix l'autenticació"

, "Username"
: "Nom d'usuari"

, "Database"
: "Base de dades"

, "User"
: "Usuari"

, "Prefix"
: "Prefix"

, "Logging"
: "Registre d'esdeveniments"

, "Filename"
: "Nom de fitxer"

, "Priority"
: "Prioritat"

, "Caching"
: "Emmagatzematge cau"

, "Lifetime (seconds)"
: "temps de vida (segons)"

, "Path"
: "Camí"

, "Queue"
: ""

, "Session"
: ""

, "Temporary files"
: "Fitxers temporals"

, "Temporary Files Path"
: "Camí als fitxers temporals"

, "Filestore directory"
: ""

, "Filestore Path"
: ""

, "Addressbook Map panel"
: "Tauler Mapa de llibreta d'adreces"

, "Map panel"
: "Tauler Mapa"

, "disabled"
: "inhabilitat"

, "enabled"
: "habilitat"

, "Config file is not writable"
: "El fitxer de configuració no es pot escriure"

, "Download config file"
: "Descarrega el fitxer de configuració"

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Standard IMAP"
: "IMAP estàndard"

, "Standard SMTP"
: "SMTP estàndard"

, "Imap"
: "Imap"

, "Verify peer Certificate"
: ""

, "Use system account"
: "Utilitza el compte de sistema"

, "Use email address as login name"
: ""

, "Cyrus Admin"
: ""

, "Cyrus Admin Password"
: ""

, "Use proxy auth"
: ""

, "Smtp"
: "Smtp"

, "Authentication"
: "Autenticació"

, "Login"
: "Inici de sessió"

, "Plain"
: "Pla"

, "Primary Domain"
: "Domini primari"

, "Secondary Domains (comma separated)"
: "Dominis secundaris (separats per comes)"

, "Notifications service address"
: "Adreça del servei de notificacions"

, "Notification Username"
: "Nom d'usuari de notificació"

, "Notification Password"
: "Contrasenya de notificació"

, "Notifications local client (hostname or IP address)"
: ""

, "SIEVE"
: ""

, "MySql Hostname"
: "Nom de l'amfitrió MySql"

, "MySql Database"
: "Base de dades MySql"

, "MySql User"
: "Usuari MySql"

, "MySql Password"
: "Contrasenya MySql"

, "MySql Port"
: "Port MySql"

, "User or UID"
: ""

, "Group or GID"
: ""

, "Home Template"
: ""

, "Password Scheme"
: ""

, "PLAIN-MD5"
: ""

, "MD5-CRYPT"
: ""

, "SHA1"
: ""

, "SHA256"
: ""

, "SSHA256"
: ""

, "SHA512"
: ""

, "SSHA512"
: ""

, "PLAIN"
: ""

, "Setup"
: ""

, "Application, Applications"
: [
  "Aplicació"
 ,"Aplicacions"

]
, "Terms and Conditions"
: "Termes i condicions"

, "Setup Checks"
: "Proves de configuració"

, "Config Manager"
: "Gestor de configuracions"

, "Authentication/Accounts"
: "Autenticació/Comptes"

, "Email"
: "Correu electrònic"

, "Application Manager"
: "Gestor d'aplicacions"

, "I have read the license agreement and accept it"
: "He llegit i acceptat l'acord de llicència"

, "License Agreement"
: "Acord de llicència"

, "I have read the privacy agreement and accept it"
: "He llegit i acceptat l'acord de privadesa"

, "Privacy Agreement"
: "Acord de privadesa"

, "Accept Terms and Conditions"
: "Accepta els termes i condicions"


, "Application"
: "Aplicació"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
